from .other import middle,change,find_path
from .percent import per_of,per_is,per_from